==> airbridge_flutter_sdk-1.0.0.tar.gz: android/src/main/java/co/ab180/airbridge/flutter/PlacementAPI.java <==
package co.ab180.airbridge.flutter;

import java.util.HashMap;

import io.airbridge.AirBridge;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

public class PlacementAPI implements MethodChannel.MethodCallHandler {

    //
    // flutter plugin setting
    //

    public static void registerWith(PluginRegistry.Registrar registrar) {
        final MethodChannel channel = new MethodChannel(
                registrar.messenger(),
                "airbridge_flutter_sdk/method/placement"
        );
        channel.setMethodCallHandler(new PlacementAPI());
    }

    @Override
    public void onMethodCall(MethodCall call, MethodChannel.Result result) {
        HashMap arguments = Get.type(HashMap.class, call.arguments);

        if (call.method.equals("click")) {
            click(arguments, result);
        } else if (call.method.equals("impression")) {
            impression(arguments, result);
        } else {
            result.notImplemented();
        }
    }

    //
    // flutter method
    //

    private void click(HashMap arguments, MethodChannel.Result result) {
        String trackingLink = Get.type(String.class, arguments, "trackingLink");
        String deeplink = Get.type(String.class, arguments, "deeplink");
        String fallback = Get.type(String.class, arguments, "fallback");

        AirBridge.getPlacement().click(trackingLink, deeplink, fallback);

        result.success(null);
    }

    private void impression(HashMap arguments, MethodChannel.Result result) {
        String trackingLink = Get.type(String.class, arguments, "trackingLink");

        AirBridge.getPlacement().impression(trackingLink);

        result.success(null);
    }
}

==> airbridge_flutter_sdk-1.1.1.tar.gz: android/src/main/java/co/ab180/airbridge/flutter/PlacementAPI.java <==
package co.ab180.airbridge.flutter;

import java.util.HashMap;
import java.util.Map;

import co.ab180.airbridge.Airbridge;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

public class PlacementAPI implements MethodChannel.MethodCallHandler {

    //
    // flutter plugin setting
    //

    public static void registerWith(PluginRegistry.Registrar registrar) {
        final MethodChannel channel = new MethodChannel(
                registrar.messenger(),
                "airbridge_flutter_sdk/method/placement"
        );
        channel.setMethodCallHandler(new PlacementAPI());
    }

    @Override
    public void onMethodCall(MethodCall call, MethodChannel.Result result) {
        Map<?, ?> arguments = Get.type(HashMap.class, call.arguments);

        if (call.method.equals("click")) {
            click(arguments, result);
        } else if (call.method.equals("impression")) {
            impression(arguments, result);
        } else {
            result.notImplemented();
        }
    }

    //
    // flutter method
    //

    private void click(Map<?, ?> arguments, MethodChannel.Result result) {
        String trackingLink = Get.type(String.class, arguments, "trackingLink");
        String deeplink = Get.type(String.class, arguments, "deeplink");
        String fallback = Get.type(String.class, arguments, "fallback");

        Airbridge.click(trackingLink, deeplink, fallback);

        result.success(null);
    }

    private void impression(Map<?, ?> arguments, MethodChannel.Result result) {
        String trackingLink = Get.type(String.class, arguments, "trackingLink");

        Airbridge.impression(trackingLink);

        result.success(null);
    }
}
